namespace DataGridNumbersOnly
{
	using System;
	using System.ComponentModel;
	using System.Data;
	using System.Drawing;
	using System.Windows.Forms;

	public class Form1 : System.Windows.Forms.Form
	{
		private System.ComponentModel.Container components;
		private DataGrid myDataGrid;   
		private DataSet myDataSet;
		private bool TablesAlreadyAdded;
		
		public Form1()
		{
			// Required for Windows Form Designer support.
			InitializeComponent();
			// Call SetUp to bind the controls.
			SetUp();
		}
	

		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if (components != null)
				{
					components.Dispose();}
			}
			base.Dispose( disposing );
		}
		private void InitializeComponent()
		{
			this.myDataGrid = new System.Windows.Forms.DataGrid();
			((System.ComponentModel.ISupportInitialize)(this.myDataGrid)).BeginInit();
			this.SuspendLayout();
			
			// 
			// myDataGrid
			// 
			this.myDataGrid.CaptionText = "Microsoft DataGrid Control";
			this.myDataGrid.DataMember = "";
			this.myDataGrid.HeaderForeColor = System.Drawing.SystemColors.ControlText;
			this.myDataGrid.Location = new System.Drawing.Point(24, 50);
			this.myDataGrid.Name = "myDataGrid";
			this.myDataGrid.Size = new System.Drawing.Size(300, 200);
			this.myDataGrid.TabIndex = 2;
			this.myDataGrid.MouseUp += new System.Windows.Forms.MouseEventHandler(this.Grid_MouseUp);
			// 
			// Form1
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(450, 330);
			this.Controls.AddRange(new System.Windows.Forms.Control[] {
																		  this.myDataGrid});
			this.Name = "Form1";
			this.Text = "DataGrid Control Sample";
			((System.ComponentModel.ISupportInitialize)(this.myDataGrid)).EndInit();
			this.ResumeLayout(false);

		}

		public static void Main()
		{
			Application.Run(new Form1());
		}
	   
		private void SetUp()
		{
			// Create a DataSet with two tables and one relation.
			MakeDataSet();
			/* Bind the DataGrid to the DataSet. The dataMember
			specifies that the Customers table should be displayed.*/
			myDataGrid.SetDataBinding(myDataSet, "Customers");

			//create and add a custom table style so we can
			//easily get at the behavior of a cell...
			AddCustomDataTableStyle();
		}

		

		private void AddCustomDataTableStyle()
		{
			DataGridTableStyle ts1 = new DataGridTableStyle();
			ts1.MappingName = "Customers";
			// Set other properties.
			ts1.AlternatingBackColor = Color.LightGray;
			//
			/* Use a PropertyDescriptor to create a formatted
		column. First get the PropertyDescriptorCollection
		for the data source and data member. */
			PropertyDescriptorCollection pdc = this.BindingContext
				[myDataSet, "Customers"].GetItemProperties();
	 
			/* Create a formatted column using a PropertyDescriptor.
			The formatting character "i" specifies a integer format. */     
			DataGridDigitsTextBoxColumn csIDInt = 
				new DataGridDigitsTextBoxColumn(pdc["CustID"], "i", true);
			csIDInt.MappingName = "CustID";
			csIDInt.HeaderText = "CustID";
			csIDInt.Width = 60;
			ts1.GridColumnStyles.Add(csIDInt);
			//




			/* Add a GridColumnStyle and set its MappingName 
			to the name of a DataColumn in the DataTable. 
			Set the HeaderText and Width properties. */
	      
			DataGridColumnStyle boolCol = new DataGridBoolColumn();
			boolCol.MappingName = "Current";
			boolCol.HeaderText = "IsCurrent Customer";
			boolCol.Width = 150;
			ts1.GridColumnStyles.Add(boolCol);
	      
			// Add a second column style.
			DataGridColumnStyle TextCol = new DataGridTextBoxColumn();
			TextCol.MappingName = "custName";
			TextCol.HeaderText = "Customer Name";
			TextCol.Width = 250;
			ts1.GridColumnStyles.Add(TextCol);

			
			/* Add the DataGridTableStyle instances to 
			the GridTableStylesCollection. */
			myDataGrid.TableStyles.Add(ts1);
			
			
		}

		
		private void Grid_MouseUp(object sender, MouseEventArgs e)
		{
			// Create a HitTestInfo object using the HitTest method.

			// Get the DataGrid by casting sender.
			DataGrid myGrid = (DataGrid)sender;
			DataGrid.HitTestInfo myHitInfo = myGrid.HitTest(e.X, e.Y);
			Console.WriteLine(myHitInfo);
			Console.WriteLine(myHitInfo.Type);
			Console.WriteLine(myHitInfo.Row);
			Console.WriteLine(myHitInfo.Column);
		}

		// Create a DataSet with two tables and populate it.
		private void MakeDataSet()
		{
			// Create a DataSet.
			myDataSet = new DataSet("myDataSet");
	      
			// Create two DataTables.
			DataTable tCust = new DataTable("Customers");
			
			// Create two columns, and add them to the first table.
			DataColumn cCustID = new DataColumn("CustID", typeof(int));
			DataColumn cCustName = new DataColumn("CustName");
			DataColumn cCurrent = new DataColumn("Current", typeof(bool));
			tCust.Columns.Add(cCustID);
			tCust.Columns.Add(cCustName);
			tCust.Columns.Add(cCurrent);

			// Add the tables to the DataSet.
			myDataSet.Tables.Add(tCust);
			
	   
			/* Populates the tables. For each customer and order, 
			creates two DataRow variables. */
			DataRow newRow1;
			
			// Create three customers in the Customers Table.
			for(int i = 1; i < 4; i++)
			{
				newRow1 = tCust.NewRow();
				newRow1["custID"] = i;
				// Add the row to the Customers table.
				tCust.Rows.Add(newRow1);
			}
			// Give each customer a distinct name.
			tCust.Rows[0]["custName"] = "Alpha";
			tCust.Rows[1]["custName"] = "Beta";
			tCust.Rows[2]["custName"] = "Omega";

			// Give the Current column a value.
			tCust.Rows[0]["Current"] = true;
			tCust.Rows[1]["Current"] = true;
			tCust.Rows[2]["Current"] = false;
		}
	}

	public class DataGridDigitsTextBoxColumn : DataGridTextBoxColumn
	{
		public DataGridDigitsTextBoxColumn(System.ComponentModel.PropertyDescriptor pd, string format, bool b)
			: base(pd, format, b)
		{
			this.TextBox.KeyPress += new System.Windows.Forms.KeyPressEventHandler(HandleKeyPress);
		  
		}

		private void HandleKeyPress(object sender, System.Windows.Forms.KeyPressEventArgs e)
		{
			//ignore if not digit or control key
			if(!char.IsDigit(e.KeyChar) && !char.IsControl(e.KeyChar))
				e.Handled = true;

			//ignore if more than 3 digits 
			if(this.TextBox.Text.Length >= 3 && !char.IsControl(e.KeyChar) && this.TextBox.SelectionLength == 0)
				e.Handled = true;
		}

		protected override void Dispose(bool disposing)
		{
			if(disposing)
				this.TextBox.KeyPress -= new System.Windows.Forms.KeyPressEventHandler(HandleKeyPress);

			base.Dispose(disposing);
		  
		}
	}
}
